@@ -6,10 +6,13 @@ import signal
 import platform
 import multiprocessing
 from contextlib import closing
-
-import sqlite3
 import pytest
 
+try:
+    import sqlean as sqlite3
+except ImportError:
+    import sqlite3
+
 from litecli.main import special
 
 DATABASE = "test.sqlite3"
